==> flavortext-1.0.2-py3-none-any.whl: flavortext/flavortext.py <==
from random import choice
from time import sleep

# Define the built in lists of words
constructiveVerbs = [
    "Align",
    "Build",
    "Calibrat",
    "Instanc",
    "Configur",
    "Snort",
    "Microwav",
    "Tweak",
    "Wrangl",
    "Hack",
    "Pwn",
    "Boot",
    "Allocat",
    "Bind",
    "Revv",
    "Polish",
    "Fabricat",
    "Ping",
    "Refactor",
    "Load",
    "Quantify",
    "Assembl",
    "Distill",
    "Bak",
    "Receiv",
    "Unlock",
    "Compil",
    "Pressuriz",
    "Chooch",
    "Mak",
    "Engag",
    "Decrypt",
    "Synthesiz",
    "Predict",
    "Analyz",
    "Dispens",
    "Fir",
    "Insert",
    "Align",
    "Encourag",
    "Extrud",
    "Access",
    "Sharpen",
    "Enhanc",
    "Crank",
    "Stack",
    "Craft",
    "Render",
    "Mount",
    "Generat",
    "Implement",
    "Download",
    "Construct",
    "Wow! Amaz",
    "Moisten",
    "Customiz",
    "Compensat",
    "Buffer",
    "Transferr",
    "Induct",
    "Emitt",
    "Unzipp",
    "Squirt",
    "Feed",
    "Buy",
    "Spark",
    "Implant",
    "Triangulat",
    "Inject",
    "Link",
    "Brew",
    "Process",
    "Deploy",
    "Tun",
    "Attach",
    "Train",
    "Ignor",
    "Tapp",
    "Reload",
    "Simulat",
    "Fluff",
    "Fill",
    "Sort",
    "Updat",
    "Upgrad",
    "Prim",
    "Trac",
    "Inflat",
    "Wangjangl",
    "Charg",
    "Crack",
    "Ignor",
    "Activat",
    "Dial",
    "Pimp",
    "Collect",
    "Approach",
    "Approv",
    "Sampl",
    "Energiz",
    "Stuff"
]

destructiveVerbs = [
    "Deallocat",
    "Trash",
    "Unplugg",
    "Revok",
    "Forgett",
    "Discard",
    "Dropp",
    "Holster",
    "Shredd",
    "Jettison",
    "Dissolv",
    "Liquidat",
    "Releas",
    "Collimat",
    "Eject",
    "Ditch",
    "Leak",
    "Sell",
    "Banish",
    "Dereferenc",
    "Sacrific",
    "Desolder",
    "Destruct",
    "Decompil",
    "Blow",
    "Disengag",
    "Digest",
    "Smash",
    "Encrypt",
    "Crash",
    "Lock",
    "Purg",
    "Regrett",
    "Rewind",
    "Free",
    "Delet",
    "Clos",
    "Retract",
    "Collaps",
    "Liquefy",
    "Derezz",
    "Stow",
    "Archiv",
    "Suspend",
    "Suppress",
    "Clean",
    "Squash",
    "Secur",
    "Withdraw",
    "Dump",
    "Obfuscat",
    "Break",
    "Scrubb",
    "Abandon",
    "Flatten",
    "Stash",
    "Finish",
    "Evacuat",
    "Scrambl",
    "Recycl",
    "Crush",
    "Zipp",
    "Unload",
    "Disconnect",
    "Loosen",
    "Contain",
    "Debat",
    "Detach",
    "Neutraliz",
    "Salvag",
    "Empty",
    "Hid",
    "Disarm",
    "Pickl",
    "Disregard",
    "Yeet",
    "Scrapp",
    "Deflat",
    "Discharg",
    "Deactivat",
    "Steriliz",
    "Reliev",
    "Nuk",
    "Degauss",
    "Dismiss",
    "Drain",
    "Reject",
    "Nerf",
    "Pay",
    "Return",
    "Unstick",
    "Splitt",
    "Cancell",
    "Sham",
    "Embezzl",
    "Fling",
    "Regrett",
    "Halt",
    "Arrest",
    "Bury"
]

nouns = [
    "content",
    "your mom",
    "the shmoo",
    "API",
    "the BJT man",
    "aesthetics",
    "backstory",
    "tactics",
    "bugs",
    "sauce",
    "warp drive",
    "data",
    "the funk",
    "AI",
    "crystals",
    "spaghetti",
    "fluxgate",
    "electrons",
    "loud noises",
    "wires",
    "bytecode",
    "the truth",
    "magic",
    "hot lava",
    "bits",
    "Brad",
    "Teensy",
    "sensors",
    "photons",
    "signal",
    "the planet",
    "password",
    "chips",
    "circuits",
    "privacy",
    "synergy",
    "widgets",
    "love",
    "packets",
    "reality",
    "lasers",
    "protocols",
    "voltage",
    "registers",
    "puns",
    "dogecoins",
    "kittens",
    "magic smoke",
    "plot device",
    "the core",
    "dank memes",
    "subroutines",
    "radiation",
    "steam",
    "trousers",
    "beer",
    "protocol",
    "one-liners",
    "the Gibson",
    "software",
    "a fat one",
    "holograms",
    "magnets",
    "inductors",
    "resistors",
    "capacitors",
    "viewers",
    "subscribers",
    "sausage",
    "my wife",
    "drama",
    "the future",
    "vectors",
    "the clowns",
    "a Palm Pilot",
    "5G implant",
    "monkeys",
    "breadboard",
    "Patreon",
    "money",
    "the Internet",
    "fluids",
    "the impostor",
    "beats",
    "dopamine",
    "fedora",
    "neural net",
    "comments",
    "ports",
    "you. Yes you",
    "mixtape",
    "[REDACTED]",
    "hot tub",
    "paperwork",
    "Nerf",
    "cyber-doobie",
    "the 1%",
    "the Matrix",
    "variables",
    "IP address"
]

# color text possibilities
colors = [
    '\u001b[31m',
    '\u001b[32m',
    '\u001b[33m',
    '\u001b[34m',
    '\u001b[35m',
    '\u001b[36m',
    '\u001b[37m',
    '\u001b[91m',
    '\u001b[92m',
    '\u001b[93m',
    '\u001b[94m',
    '\u001b[95m',
    '\u001b[96m',
    '\u001b[97m',
]

# generate and print flavoricious text
def flavortext(yourConstrVerbs = None, yourDestrVerbs = None, yourNouns = None, length = 30, delay = 0.05):
    # append the user provided funny words, if available
    if yourConstrVerbs:
        constructiveVerbs.extend(yourConstrVerbs)
    if yourDestrVerbs:
        destructiveVerbs.extend(yourDestrVerbs)
    if yourNouns:
        nouns.extend(yourNouns)

    # Pick some stuff then print the line
    for i in range(length):
        conOrDest = choice([1,2])
        if conOrDest == 1:
            verb = choice(constructiveVerbs)
            noun = choice(nouns)
            color = choice(colors)
            print(f'{color}{verb}ing {noun}\u001b[0m')
        sleep(delay)
        if conOrDest == 2:
            verb = choice(destructiveVerbs)
            noun = choice(nouns)
            color = choice(colors)
            print(f'{color}{verb}ing {noun}\u001b[0m')
        sleep(delay)


#---@@@---# You can't spell 'flavortext' without 'vortex' #---@@@---#

==> flavortext-1.0.3-py3-none-any.whl: flavortext/flavortext.py <==
from random import choice
from time import sleep

# Define the built in lists of words
constructiveVerbs = [
    "Align",
    "Build",
    "Calibrat",
    "Instanc",
    "Configur",
    "Snort",
    "Microwav",
    "Tweak",
    "Wrangl",
    "Hack",
    "Pwn",
    "Boot",
    "Allocat",
    "Bind",
    "Revv",
    "Polish",
    "Fabricat",
    "Ping",
    "Refactor",
    "Load",
    "Quantify",
    "Assembl",
    "Distill",
    "Bak",
    "Receiv",
    "Unlock",
    "Compil",
    "Pressuriz",
    "Chooch",
    "Mak",
    "Engag",
    "Decrypt",
    "Synthesiz",
    "Predict",
    "Analyz",
    "Dispens",
    "Fir",
    "Insert",
    "Align",
    "Encourag",
    "Extrud",
    "Access",
    "Sharpen",
    "Enhanc",
    "Crank",
    "Stack",
    "Craft",
    "Render",
    "Mount",
    "Generat",
    "Implement",
    "Download",
    "Construct",
    "Wow! Amaz",
    "Moisten",
    "Customiz",
    "Compensat",
    "Buffer",
    "Transferr",
    "Induct",
    "Emitt",
    "Unzipp",
    "Squirt",
    "Feed",
    "Buy",
    "Spark",
    "Implant",
    "Triangulat",
    "Inject",
    "Link",
    "Brew",
    "Process",
    "Deploy",
    "Tun",
    "Attach",
    "Train",
    "Ignor",
    "Tapp",
    "Reload",
    "Simulat",
    "Fluff",
    "Fill",
    "Sort",
    "Updat",
    "Upgrad",
    "Prim",
    "Trac",
    "Inflat",
    "Wangjangl",
    "Charg",
    "Crack",
    "Ignor",
    "Activat",
    "Dial",
    "Pimp",
    "Collect",
    "Approach",
    "Approv",
    "Sampl",
    "Energiz",
    "Stuff"
]

destructiveVerbs = [
    "Deallocat",
    "Trash",
    "Unplugg",
    "Revok",
    "Forgett",
    "Discard",
    "Dropp",
    "Holster",
    "Shredd",
    "Jettison",
    "Dissolv",
    "Liquidat",
    "Releas",
    "Collimat",
    "Eject",
    "Ditch",
    "Leak",
    "Sell",
    "Banish",
    "Dereferenc",
    "Sacrific",
    "Desolder",
    "Destruct",
    "Decompil",
    "Blow",
    "Disengag",
    "Digest",
    "Smash",
    "Encrypt",
    "Crash",
    "Lock",
    "Purg",
    "Regrett",
    "Rewind",
    "Free",
    "Delet",
    "Clos",
    "Retract",
    "Collaps",
    "Liquefy",
    "Derezz",
    "Stow",
    "Archiv",
    "Suspend",
    "Suppress",
    "Clean",
    "Squash",
    "Secur",
    "Withdraw",
    "Dump",
    "Obfuscat",
    "Break",
    "Scrubb",
    "Abandon",
    "Flatten",
    "Stash",
    "Finish",
    "Evacuat",
    "Scrambl",
    "Recycl",
    "Crush",
    "Zipp",
    "Unload",
    "Disconnect",
    "Loosen",
    "Contain",
    "Debat",
    "Detach",
    "Neutraliz",
    "Salvag",
    "Empty",
    "Hid",
    "Disarm",
    "Pickl",
    "Disregard",
    "Yeet",
    "Scrapp",
    "Deflat",
    "Discharg",
    "Deactivat",
    "Steriliz",
    "Reliev",
    "Nuk",
    "Degauss",
    "Dismiss",
    "Drain",
    "Reject",
    "Nerf",
    "Pay",
    "Return",
    "Unstick",
    "Splitt",
    "Cancell",
    "Sham",
    "Embezzl",
    "Fling",
    "Regrett",
    "Halt",
    "Arrest",
    "Bury"
]

nouns = [
    "content",
    "your mom",
    "the shmoo",
    "API",
    "the BJT man",
    "aesthetics",
    "backstory",
    "tactics",
    "bugs",
    "sauce",
    "warp drive",
    "data",
    "the funk",
    "AI",
    "crystals",
    "spaghetti",
    "fluxgate",
    "electrons",
    "loud noises",
    "wires",
    "bytecode",
    "the truth",
    "magic",
    "hot lava",
    "bits",
    "Brad",
    "Teensy",
    "sensors",
    "photons",
    "signal",
    "the planet",
    "password",
    "chips",
    "circuits",
    "privacy",
    "synergy",
    "widgets",
    "love",
    "packets",
    "reality",
    "lasers",
    "protocols",
    "voltage",
    "registers",
    "puns",
    "dogecoins",
    "kittens",
    "magic smoke",
    "plot device",
    "the core",
    "dank memes",
    "subroutines",
    "radiation",
    "steam",
    "trousers",
    "beer",
    "protocol",
    "one-liners",
    "the Gibson",
    "software",
    "a fat one",
    "holograms",
    "magnets",
    "inductors",
    "resistors",
    "capacitors",
    "viewers",
    "subscribers",
    "sausage",
    "my wife",
    "drama",
    "the future",
    "vectors",
    "the clowns",
    "a Palm Pilot",
    "5G implant",
    "monkeys",
    "breadboard",
    "Patreon",
    "money",
    "the Internet",
    "fluids",
    "the impostor",
    "beats",
    "dopamine",
    "fedora",
    "neural net",
    "comments",
    "ports",
    "you. Yes you",
    "mixtape",
    "[REDACTED]",
    "hot tub",
    "paperwork",
    "Nerf",
    "cyber-doobie",
    "the 1%",
    "the Matrix",
    "variables",
    "IP address"
]

# color text possibilities
colors = [
    '\u001b[31m',
    '\u001b[32m',
    '\u001b[33m',
    '\u001b[34m',
    '\u001b[35m',
    '\u001b[36m',
    '\u001b[37m',
    '\u001b[91m',
    '\u001b[92m',
    '\u001b[93m',
    '\u001b[94m',
    '\u001b[95m',
    '\u001b[96m',
    '\u001b[97m',
]

# generate and print flavoricious text
def flavoricious(yourConstrVerbs = None, yourDestrVerbs = None, yourNouns = None, length = 30, delay = 0.05):
    # append the user provided funny words, if available
    if yourConstrVerbs:
        constructiveVerbs.extend(yourConstrVerbs)
    if yourDestrVerbs:
        destructiveVerbs.extend(yourDestrVerbs)
    if yourNouns:
        nouns.extend(yourNouns)

    # Pick some stuff then print the line
    for i in range(length):
        conOrDest = choice([1,2])
        if conOrDest == 1:
            verb = choice(constructiveVerbs)
            noun = choice(nouns)
            color = choice(colors)
            print(f'{color}{verb}ing {noun}\u001b[0m')
        sleep(delay)
        if conOrDest == 2:
            verb = choice(destructiveVerbs)
            noun = choice(nouns)
            color = choice(colors)
            print(f'{color}{verb}ing {noun}\u001b[0m')
        sleep(delay)


#---@@@---# You can't spell 'flavortext' without 'vortex' #---@@@---#
